# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/agent.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x63ogment/api/agent.proto\x12\x07\x63ogment\x1a\x18\x63ogment/api/common.proto\"z\n\x11\x41gentStartRequest\x12\x11\n\timpl_name\x18\x01 \x01(\t\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.cogment.ActorConfig\x12,\n\x0f\x61\x63tors_in_trial\x18\x03 \x03(\x0b\x32\x13.cogment.TrialActor\"\x11\n\x0f\x41gentStartReply\"D\n\x17\x41gentObservationRequest\x12)\n\x0bobservation\x18\x01 \x01(\x0b\x32\x14.cogment.Observation\"y\n\x10\x41gentActionReply\x12\x1f\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0f.cogment.Action\x12 \n\x07rewards\x18\x02 \x03(\x0b\x32\x0f.cogment.Reward\x12\"\n\x08messages\x18\x03 \x03(\x0b\x32\x10.cogment.Message\"5\n\x12\x41gentRewardRequest\x12\x1f\n\x06reward\x18\x01 \x01(\x0b\x32\x0f.cogment.Reward\"\x12\n\x10\x41gentRewardReply\"9\n\x13\x41gentMessageRequest\x12\"\n\x08messages\x18\x01 \x03(\x0b\x32\x10.cogment.Message\"\x13\n\x11\x41gentMessageReply\"?\n\x0f\x41gentEndRequest\x12,\n\nfinal_data\x18\x01 \x01(\x0b\x32\x18.cogment.ActorPeriodData\"\x0f\n\rAgentEndReply2\xae\x03\n\rAgentEndpoint\x12\x41\n\x07OnStart\x12\x1a.cogment.AgentStartRequest\x1a\x18.cogment.AgentStartReply\"\x00\x12R\n\rOnObservation\x12 .cogment.AgentObservationRequest\x1a\x19.cogment.AgentActionReply\"\x00(\x01\x30\x01\x12\x44\n\x08OnReward\x12\x1b.cogment.AgentRewardRequest\x1a\x19.cogment.AgentRewardReply\"\x00\x12G\n\tOnMessage\x12\x1c.cogment.AgentMessageRequest\x1a\x1a.cogment.AgentMessageReply\"\x00\x12;\n\x05OnEnd\x12\x18.cogment.AgentEndRequest\x1a\x16.cogment.AgentEndReply\"\x00\x12:\n\x07Version\x12\x17.cogment.VersionRequest\x1a\x14.cogment.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])




_AGENTSTARTREQUEST = _descriptor.Descriptor(
  name='AgentStartRequest',
  full_name='cogment.AgentStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='impl_name', full_name='cogment.AgentStartRequest.impl_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogment.AgentStartRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_in_trial', full_name='cogment.AgentStartRequest.actors_in_trial', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=184,
)


_AGENTSTARTREPLY = _descriptor.Descriptor(
  name='AgentStartReply',
  full_name='cogment.AgentStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=203,
)


_AGENTOBSERVATIONREQUEST = _descriptor.Descriptor(
  name='AgentObservationRequest',
  full_name='cogment.AgentObservationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observation', full_name='cogment.AgentObservationRequest.observation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=273,
)


_AGENTACTIONREPLY = _descriptor.Descriptor(
  name='AgentActionReply',
  full_name='cogment.AgentActionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='cogment.AgentActionReply.action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogment.AgentActionReply.rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.AgentActionReply.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=396,
)


_AGENTREWARDREQUEST = _descriptor.Descriptor(
  name='AgentRewardRequest',
  full_name='cogment.AgentRewardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reward', full_name='cogment.AgentRewardRequest.reward', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=451,
)


_AGENTREWARDREPLY = _descriptor.Descriptor(
  name='AgentRewardReply',
  full_name='cogment.AgentRewardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=471,
)


_AGENTMESSAGEREQUEST = _descriptor.Descriptor(
  name='AgentMessageRequest',
  full_name='cogment.AgentMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.AgentMessageRequest.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=530,
)


_AGENTMESSAGEREPLY = _descriptor.Descriptor(
  name='AgentMessageReply',
  full_name='cogment.AgentMessageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=551,
)


_AGENTENDREQUEST = _descriptor.Descriptor(
  name='AgentEndRequest',
  full_name='cogment.AgentEndRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='final_data', full_name='cogment.AgentEndRequest.final_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=616,
)


_AGENTENDREPLY = _descriptor.Descriptor(
  name='AgentEndReply',
  full_name='cogment.AgentEndReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=633,
)

_AGENTSTARTREQUEST.fields_by_name['config'].message_type = cogment_dot_api_dot_common__pb2._ACTORCONFIG
_AGENTSTARTREQUEST.fields_by_name['actors_in_trial'].message_type = cogment_dot_api_dot_common__pb2._TRIALACTOR
_AGENTOBSERVATIONREQUEST.fields_by_name['observation'].message_type = cogment_dot_api_dot_common__pb2._OBSERVATION
_AGENTACTIONREPLY.fields_by_name['action'].message_type = cogment_dot_api_dot_common__pb2._ACTION
_AGENTACTIONREPLY.fields_by_name['rewards'].message_type = cogment_dot_api_dot_common__pb2._REWARD
_AGENTACTIONREPLY.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
_AGENTREWARDREQUEST.fields_by_name['reward'].message_type = cogment_dot_api_dot_common__pb2._REWARD
_AGENTMESSAGEREQUEST.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
_AGENTENDREQUEST.fields_by_name['final_data'].message_type = cogment_dot_api_dot_common__pb2._ACTORPERIODDATA
DESCRIPTOR.message_types_by_name['AgentStartRequest'] = _AGENTSTARTREQUEST
DESCRIPTOR.message_types_by_name['AgentStartReply'] = _AGENTSTARTREPLY
DESCRIPTOR.message_types_by_name['AgentObservationRequest'] = _AGENTOBSERVATIONREQUEST
DESCRIPTOR.message_types_by_name['AgentActionReply'] = _AGENTACTIONREPLY
DESCRIPTOR.message_types_by_name['AgentRewardRequest'] = _AGENTREWARDREQUEST
DESCRIPTOR.message_types_by_name['AgentRewardReply'] = _AGENTREWARDREPLY
DESCRIPTOR.message_types_by_name['AgentMessageRequest'] = _AGENTMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['AgentMessageReply'] = _AGENTMESSAGEREPLY
DESCRIPTOR.message_types_by_name['AgentEndRequest'] = _AGENTENDREQUEST
DESCRIPTOR.message_types_by_name['AgentEndReply'] = _AGENTENDREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgentStartRequest = _reflection.GeneratedProtocolMessageType('AgentStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _AGENTSTARTREQUEST,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentStartRequest)
  })
_sym_db.RegisterMessage(AgentStartRequest)

AgentStartReply = _reflection.GeneratedProtocolMessageType('AgentStartReply', (_message.Message,), {
  'DESCRIPTOR' : _AGENTSTARTREPLY,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentStartReply)
  })
_sym_db.RegisterMessage(AgentStartReply)

AgentObservationRequest = _reflection.GeneratedProtocolMessageType('AgentObservationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AGENTOBSERVATIONREQUEST,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentObservationRequest)
  })
_sym_db.RegisterMessage(AgentObservationRequest)

AgentActionReply = _reflection.GeneratedProtocolMessageType('AgentActionReply', (_message.Message,), {
  'DESCRIPTOR' : _AGENTACTIONREPLY,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentActionReply)
  })
_sym_db.RegisterMessage(AgentActionReply)

AgentRewardRequest = _reflection.GeneratedProtocolMessageType('AgentRewardRequest', (_message.Message,), {
  'DESCRIPTOR' : _AGENTREWARDREQUEST,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentRewardRequest)
  })
_sym_db.RegisterMessage(AgentRewardRequest)

AgentRewardReply = _reflection.GeneratedProtocolMessageType('AgentRewardReply', (_message.Message,), {
  'DESCRIPTOR' : _AGENTREWARDREPLY,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentRewardReply)
  })
_sym_db.RegisterMessage(AgentRewardReply)

AgentMessageRequest = _reflection.GeneratedProtocolMessageType('AgentMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _AGENTMESSAGEREQUEST,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentMessageRequest)
  })
_sym_db.RegisterMessage(AgentMessageRequest)

AgentMessageReply = _reflection.GeneratedProtocolMessageType('AgentMessageReply', (_message.Message,), {
  'DESCRIPTOR' : _AGENTMESSAGEREPLY,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentMessageReply)
  })
_sym_db.RegisterMessage(AgentMessageReply)

AgentEndRequest = _reflection.GeneratedProtocolMessageType('AgentEndRequest', (_message.Message,), {
  'DESCRIPTOR' : _AGENTENDREQUEST,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentEndRequest)
  })
_sym_db.RegisterMessage(AgentEndRequest)

AgentEndReply = _reflection.GeneratedProtocolMessageType('AgentEndReply', (_message.Message,), {
  'DESCRIPTOR' : _AGENTENDREPLY,
  '__module__' : 'cogment.api.agent_pb2'
  # @@protoc_insertion_point(class_scope:cogment.AgentEndReply)
  })
_sym_db.RegisterMessage(AgentEndReply)



_AGENTENDPOINT = _descriptor.ServiceDescriptor(
  name='AgentEndpoint',
  full_name='cogment.AgentEndpoint',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=636,
  serialized_end=1066,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnStart',
    full_name='cogment.AgentEndpoint.OnStart',
    index=0,
    containing_service=None,
    input_type=_AGENTSTARTREQUEST,
    output_type=_AGENTSTARTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnObservation',
    full_name='cogment.AgentEndpoint.OnObservation',
    index=1,
    containing_service=None,
    input_type=_AGENTOBSERVATIONREQUEST,
    output_type=_AGENTACTIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnReward',
    full_name='cogment.AgentEndpoint.OnReward',
    index=2,
    containing_service=None,
    input_type=_AGENTREWARDREQUEST,
    output_type=_AGENTREWARDREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnMessage',
    full_name='cogment.AgentEndpoint.OnMessage',
    index=3,
    containing_service=None,
    input_type=_AGENTMESSAGEREQUEST,
    output_type=_AGENTMESSAGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnEnd',
    full_name='cogment.AgentEndpoint.OnEnd',
    index=4,
    containing_service=None,
    input_type=_AGENTENDREQUEST,
    output_type=_AGENTENDREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogment.AgentEndpoint.Version',
    index=5,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENTENDPOINT)

DESCRIPTOR.services_by_name['AgentEndpoint'] = _AGENTENDPOINT

# @@protoc_insertion_point(module_scope)
