# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/environment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/environment.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x63ogment/api/environment.proto\x12\x07\x63ogment\x1a\x18\x63ogment/api/common.proto\"x\n\x0eObservationSet\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12.\n\x0cobservations\x18\x03 \x03(\x0b\x32\x18.cogment.ObservationData\x12\x12\n\nactors_map\x18\x04 \x03(\x05\"\x1c\n\tActionSet\x12\x0f\n\x07\x61\x63tions\x18\x01 \x03(\x0c\"~\n\x0f\x45nvStartRequest\x12\x11\n\timpl_name\x18\x01 \x01(\t\x12*\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1a.cogment.EnvironmentConfig\x12,\n\x0f\x61\x63tors_in_trial\x18\x03 \x03(\x0b\x32\x13.cogment.TrialActor\"A\n\rEnvStartReply\x12\x30\n\x0fobservation_set\x18\x01 \x01(\x0b\x32\x17.cogment.ObservationSet\"W\n\x10\x45nvActionRequest\x12&\n\naction_set\x18\x01 \x01(\x0b\x32\x12.cogment.ActionSet\x12\x1b\n\x13reply_with_snapshot\x18\x02 \x01(\x08\"\x9e\x01\n\x0e\x45nvActionReply\x12\x30\n\x0fobservation_set\x18\x01 \x01(\x0b\x32\x17.cogment.ObservationSet\x12 \n\x07rewards\x18\x02 \x03(\x0b\x32\x0f.cogment.Reward\x12\"\n\x08messages\x18\x03 \x03(\x0b\x32\x10.cogment.Message\x12\x14\n\x0c\x66inal_update\x18\x04 \x01(\x08\"7\n\x11\x45nvMessageRequest\x12\"\n\x08messages\x18\x01 \x03(\x0b\x32\x10.cogment.Message\"\x11\n\x0f\x45nvMessageReply2\xda\x02\n\x13\x45nvironmentEndpoint\x12=\n\x07OnStart\x12\x18.cogment.EnvStartRequest\x1a\x16.cogment.EnvStartReply\"\x00\x12\x44\n\x08OnAction\x12\x19.cogment.EnvActionRequest\x1a\x17.cogment.EnvActionReply\"\x00(\x01\x30\x01\x12\x43\n\tOnMessage\x12\x1a.cogment.EnvMessageRequest\x1a\x18.cogment.EnvMessageReply\"\x00\x12=\n\x05OnEnd\x12\x19.cogment.EnvActionRequest\x1a\x17.cogment.EnvActionReply\"\x00\x12:\n\x07Version\x12\x17.cogment.VersionRequest\x1a\x14.cogment.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])




_OBSERVATIONSET = _descriptor.Descriptor(
  name='ObservationSet',
  full_name='cogment.ObservationSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogment.ObservationSet.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogment.ObservationSet.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogment.ObservationSet.observations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_map', full_name='cogment.ObservationSet.actors_map', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=188,
)


_ACTIONSET = _descriptor.Descriptor(
  name='ActionSet',
  full_name='cogment.ActionSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='cogment.ActionSet.actions', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=218,
)


_ENVSTARTREQUEST = _descriptor.Descriptor(
  name='EnvStartRequest',
  full_name='cogment.EnvStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='impl_name', full_name='cogment.EnvStartRequest.impl_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogment.EnvStartRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_in_trial', full_name='cogment.EnvStartRequest.actors_in_trial', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=346,
)


_ENVSTARTREPLY = _descriptor.Descriptor(
  name='EnvStartReply',
  full_name='cogment.EnvStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observation_set', full_name='cogment.EnvStartReply.observation_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=413,
)


_ENVACTIONREQUEST = _descriptor.Descriptor(
  name='EnvActionRequest',
  full_name='cogment.EnvActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_set', full_name='cogment.EnvActionRequest.action_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_with_snapshot', full_name='cogment.EnvActionRequest.reply_with_snapshot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=502,
)


_ENVACTIONREPLY = _descriptor.Descriptor(
  name='EnvActionReply',
  full_name='cogment.EnvActionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observation_set', full_name='cogment.EnvActionReply.observation_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogment.EnvActionReply.rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.EnvActionReply.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_update', full_name='cogment.EnvActionReply.final_update', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=663,
)


_ENVMESSAGEREQUEST = _descriptor.Descriptor(
  name='EnvMessageRequest',
  full_name='cogment.EnvMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.EnvMessageRequest.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=720,
)


_ENVMESSAGEREPLY = _descriptor.Descriptor(
  name='EnvMessageReply',
  full_name='cogment.EnvMessageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=739,
)

_OBSERVATIONSET.fields_by_name['observations'].message_type = cogment_dot_api_dot_common__pb2._OBSERVATIONDATA
_ENVSTARTREQUEST.fields_by_name['config'].message_type = cogment_dot_api_dot_common__pb2._ENVIRONMENTCONFIG
_ENVSTARTREQUEST.fields_by_name['actors_in_trial'].message_type = cogment_dot_api_dot_common__pb2._TRIALACTOR
_ENVSTARTREPLY.fields_by_name['observation_set'].message_type = _OBSERVATIONSET
_ENVACTIONREQUEST.fields_by_name['action_set'].message_type = _ACTIONSET
_ENVACTIONREPLY.fields_by_name['observation_set'].message_type = _OBSERVATIONSET
_ENVACTIONREPLY.fields_by_name['rewards'].message_type = cogment_dot_api_dot_common__pb2._REWARD
_ENVACTIONREPLY.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
_ENVMESSAGEREQUEST.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
DESCRIPTOR.message_types_by_name['ObservationSet'] = _OBSERVATIONSET
DESCRIPTOR.message_types_by_name['ActionSet'] = _ACTIONSET
DESCRIPTOR.message_types_by_name['EnvStartRequest'] = _ENVSTARTREQUEST
DESCRIPTOR.message_types_by_name['EnvStartReply'] = _ENVSTARTREPLY
DESCRIPTOR.message_types_by_name['EnvActionRequest'] = _ENVACTIONREQUEST
DESCRIPTOR.message_types_by_name['EnvActionReply'] = _ENVACTIONREPLY
DESCRIPTOR.message_types_by_name['EnvMessageRequest'] = _ENVMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['EnvMessageReply'] = _ENVMESSAGEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObservationSet = _reflection.GeneratedProtocolMessageType('ObservationSet', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONSET,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ObservationSet)
  })
_sym_db.RegisterMessage(ObservationSet)

ActionSet = _reflection.GeneratedProtocolMessageType('ActionSet', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONSET,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ActionSet)
  })
_sym_db.RegisterMessage(ActionSet)

EnvStartRequest = _reflection.GeneratedProtocolMessageType('EnvStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVSTARTREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvStartRequest)
  })
_sym_db.RegisterMessage(EnvStartRequest)

EnvStartReply = _reflection.GeneratedProtocolMessageType('EnvStartReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVSTARTREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvStartReply)
  })
_sym_db.RegisterMessage(EnvStartReply)

EnvActionRequest = _reflection.GeneratedProtocolMessageType('EnvActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVACTIONREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvActionRequest)
  })
_sym_db.RegisterMessage(EnvActionRequest)

EnvActionReply = _reflection.GeneratedProtocolMessageType('EnvActionReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVACTIONREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvActionReply)
  })
_sym_db.RegisterMessage(EnvActionReply)

EnvMessageRequest = _reflection.GeneratedProtocolMessageType('EnvMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVMESSAGEREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvMessageRequest)
  })
_sym_db.RegisterMessage(EnvMessageRequest)

EnvMessageReply = _reflection.GeneratedProtocolMessageType('EnvMessageReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVMESSAGEREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvMessageReply)
  })
_sym_db.RegisterMessage(EnvMessageReply)



_ENVIRONMENTENDPOINT = _descriptor.ServiceDescriptor(
  name='EnvironmentEndpoint',
  full_name='cogment.EnvironmentEndpoint',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=742,
  serialized_end=1088,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnStart',
    full_name='cogment.EnvironmentEndpoint.OnStart',
    index=0,
    containing_service=None,
    input_type=_ENVSTARTREQUEST,
    output_type=_ENVSTARTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnAction',
    full_name='cogment.EnvironmentEndpoint.OnAction',
    index=1,
    containing_service=None,
    input_type=_ENVACTIONREQUEST,
    output_type=_ENVACTIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnMessage',
    full_name='cogment.EnvironmentEndpoint.OnMessage',
    index=2,
    containing_service=None,
    input_type=_ENVMESSAGEREQUEST,
    output_type=_ENVMESSAGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnEnd',
    full_name='cogment.EnvironmentEndpoint.OnEnd',
    index=3,
    containing_service=None,
    input_type=_ENVACTIONREQUEST,
    output_type=_ENVACTIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogment.EnvironmentEndpoint.Version',
    index=4,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENVIRONMENTENDPOINT)

DESCRIPTOR.services_by_name['EnvironmentEndpoint'] = _ENVIRONMENTENDPOINT

# @@protoc_insertion_point(module_scope)
