# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/hooks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/hooks.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x63ogment/api/hooks.proto\x12\x07\x63ogment\x1a\x18\x63ogment/api/common.proto\"[\n\x0fPreTrialContext\x12\x11\n\timpl_name\x18\x01 \x01(\t\x12$\n\x06params\x18\x02 \x01(\x0b\x32\x14.cogment.TrialParams\x12\x0f\n\x07user_id\x18\x03 \x01(\t2\x8c\x01\n\nTrialHooks\x12\x42\n\nOnPreTrial\x12\x18.cogment.PreTrialContext\x1a\x18.cogment.PreTrialContext\"\x00\x12:\n\x07Version\x12\x17.cogment.VersionRequest\x1a\x14.cogment.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])




_PRETRIALCONTEXT = _descriptor.Descriptor(
  name='PreTrialContext',
  full_name='cogment.PreTrialContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='impl_name', full_name='cogment.PreTrialContext.impl_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='cogment.PreTrialContext.params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogment.PreTrialContext.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=153,
)

_PRETRIALCONTEXT.fields_by_name['params'].message_type = cogment_dot_api_dot_common__pb2._TRIALPARAMS
DESCRIPTOR.message_types_by_name['PreTrialContext'] = _PRETRIALCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PreTrialContext = _reflection.GeneratedProtocolMessageType('PreTrialContext', (_message.Message,), {
  'DESCRIPTOR' : _PRETRIALCONTEXT,
  '__module__' : 'cogment.api.hooks_pb2'
  # @@protoc_insertion_point(class_scope:cogment.PreTrialContext)
  })
_sym_db.RegisterMessage(PreTrialContext)



_TRIALHOOKS = _descriptor.ServiceDescriptor(
  name='TrialHooks',
  full_name='cogment.TrialHooks',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=156,
  serialized_end=296,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnPreTrial',
    full_name='cogment.TrialHooks.OnPreTrial',
    index=0,
    containing_service=None,
    input_type=_PRETRIALCONTEXT,
    output_type=_PRETRIALCONTEXT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogment.TrialHooks.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIALHOOKS)

DESCRIPTOR.services_by_name['TrialHooks'] = _TRIALHOOKS

# @@protoc_insertion_point(module_scope)
